==> estateplat-common-1.1.0-20160929.061130-199-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzYgdj.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * Created with IntelliJ IDEA.
 * 预告登记信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:25
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_ygdj")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzYgdj implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //不动产坐落
    @XmlElement(name = "bdczl")
    private String bdczl;
    //义务人
    @XmlElement(name = "ywr")
    private String ywr;
    //义务人证件种类
    @XmlElement(name = "ywrzjzl")
    private String ywrzjzl;
    //义务人证件号
    @XmlElement(name = "ywrzjh")
    private String ywrzjh;
    //预告登记种类
    @XmlElement(name = "ygdjzl")
    private String ygdjzl;
    //土地使用权人
    @XmlElement(name = "tdsyqr")
    private String tdsyqr;
    //规划用途
    @XmlElement(name = "ghyt")
    private String ghyt;
    //房屋性质
    @XmlElement(name = "fwxz")
    private String fwxz;
    //房屋结构
    @XmlElement(name = "fwjg")
    private String fwjg;
    //所在层
    @XmlElement(name = "szc")
    private Integer szc;
    //总层数
    @XmlElement(name = "zcs")
    private Integer zcs;
    //建筑面积
    @XmlElement(name = "jzmj")
    private Double jzmj;
    //取得价格/被担保主债权数额
    @XmlElement(name = "qdjg")
    private Double qdjg;
    //备注
    @XmlElement(name = "bz")
    private String bz;
     //所在名义层
    @XmlElement(name = "szmyc")
    private String szmyc;
    //其他
    @XmlElement(name = "qt")
    private String qt;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }


    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getBdczl() {
        return bdczl;
    }

    public void setBdczl(String bdczl) {
        this.bdczl = bdczl;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20201124.090756-545-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzYgdj.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * Created with IntelliJ IDEA.
 * 预告登记信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:25
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_ygdj")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzYgdj implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //不动产坐落
    @XmlElement(name = "bdczl")
    private String bdczl;
    //义务人
    @XmlElement(name = "ywr")
    private String ywr;
    //义务人证件种类
    @XmlElement(name = "ywrzjzl")
    private String ywrzjzl;
    //义务人证件号
    @XmlElement(name = "ywrzjh")
    private String ywrzjh;
    //预告登记种类
    @XmlElement(name = "ygdjzl")
    private String ygdjzl;
    //土地使用权人
    @XmlElement(name = "tdsyqr")
    private String tdsyqr;
    //规划用途
    @XmlElement(name = "ghyt")
    private String ghyt;
    //房屋性质
    @XmlElement(name = "fwxz")
    private String fwxz;
    //房屋结构
    @XmlElement(name = "fwjg")
    private String fwjg;
    //所在层
    @XmlElement(name = "szc")
    private Integer szc;
    //总层数
    @XmlElement(name = "zcs")
    private Integer zcs;
    //建筑面积
    @XmlElement(name = "jzmj")
    private Double jzmj;
    //取得价格/被担保主债权数额
    @XmlElement(name = "qdjg")
    private Double qdjg;
    //备注
    @XmlElement(name = "bz")
    private String bz;
     //所在名义层
    @XmlElement(name = "szmyc")
    private String szmyc;
    //其他
    @XmlElement(name = "qt")
    private String qt;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }


    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getBdczl() {
        return bdczl;
    }

    public void setBdczl(String bdczl) {
        this.bdczl = bdczl;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
